@@ -6,9 +6,8 @@
 # pylint: disable=wildcard-import
 
 import enum
-import functools
 import typing
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Dict,  Optional
 
 from deserialize.conversions import camel_case, pascal_case
 from deserialize.decorators import constructed, _call_constructed
@@ -30,7 +29,6 @@ from deserialize.decorators import allow_unhandled, _should_allow_unhandled
 from deserialize.exceptions import (
     DeserializeException,
     InvalidBaseTypeException,
-    NoDefaultSpecifiedException,
     UndefinedDowncastException,
     UnhandledFieldException,
 )
@@ -45,13 +43,13 @@ class RawStorageMode(enum.Enum):
     """
 
     # Do not store the raw data at all
-    none = "none"
+    NONE = "none"
 
     # Only store the data on the root node
-    root = "root"
+    ROOT = "root"
 
     # Store on all objects (WARNING: This can use a significant amount of memory)
-    all = "all"
+    ALL = "all"
 
     def child_mode(self) -> "RawStorageMode":
         """Determine the mode for child parsing.
@@ -64,20 +62,20 @@ class RawStorageMode(enum.Enum):
 
         :returns: The child raw storage mode
         """
-        if self == RawStorageMode.none:
-            return RawStorageMode.none
+        if self == RawStorageMode.NONE:
+            return RawStorageMode.NONE
 
-        if self == RawStorageMode.root:
-            return RawStorageMode.none
+        if self == RawStorageMode.ROOT:
+            return RawStorageMode.NONE
 
-        if self == RawStorageMode.all:
-            return RawStorageMode.all
+        if self == RawStorageMode.ALL:
+            return RawStorageMode.ALL
 
         raise DeserializeException(f"Unexpected raw storage mode: {self}")
 
 
 # pylint: disable=function-redefined
-def deserialize(class_reference, data, *, throw_on_unhandled: bool = False, raw_storage_mode: RawStorageMode = RawStorageMode.none):  # type: ignore
+def deserialize(class_reference, data, *, throw_on_unhandled: bool = False, raw_storage_mode: RawStorageMode = RawStorageMode.NONE):  # type: ignore
     """Deserialize data to a Python object."""
 
     if not isinstance(data, dict) and not isinstance(data, list):
@@ -101,6 +99,7 @@ def deserialize(class_reference, data, *, throw_on_unhandled: bool = False, raw_
 
 # pylint: enable=function-redefined
 
+
 # pylint:disable=too-many-return-statements
 def _deserialize(
     class_reference, data, debug_name, *, throw_on_unhandled: bool, raw_storage_mode: RawStorageMode
@@ -127,7 +126,7 @@ def _deserialize(
         """Run through any finalization steps before returning the value."""
 
         # Set raw data where applicable
-        if raw_storage_mode in [RawStorageMode.root, RawStorageMode.all]:
+        if raw_storage_mode in [RawStorageMode.ROOT, RawStorageMode.ALL]:
             # We can't set attributes on primitive types
             if hasattr(value, "__dict__"):
                 setattr(value, "__deserialize_raw__", data)
@@ -175,9 +174,11 @@ def _deserialize(
             return finalize(class_reference(data))
         # pylint:disable=bare-except
         except:
+            # pylint: disable=raise-missing-from
             raise DeserializeException(
                 f"Cannot deserialize '{type(data)}' to '{class_reference}' for '{debug_name}'"
             )
+        # pylint:enable=bare-except,raise-missing-from
 
     if isinstance(data, dict):
         return finalize(
@@ -236,7 +237,6 @@ def _deserialize_list(
     throw_on_unhandled: bool,
     raw_storage_mode: RawStorageMode,
 ):
-
     if not isinstance(list_data, list):
         raise DeserializeException(
             f"Cannot deserialize '{type(list_data)}' as a list for {debug_name}."
@@ -287,7 +287,6 @@ def _deserialize_dict(
         result = {}
 
         for dict_key, dict_value in data.items():
-
             if key_type != Any and not isinstance(dict_key, key_type):
                 raise DeserializeException(
                     f"Could not deserialize key {dict_key} to type {key_type} for {debug_name}"
